FaceDetectionApi class

Constructors

FaceDetectionApi()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

detectFaces(Uint8List imageBytes) Future<List<Map<String, dynamic>>>
forceKillServer() Future<void>
startServer() Future<void>
stopServer() → void
waitForServer(String url, {int retries = 10}) Future<void>